@@ -112,7 +112,6 @@ create_deb_gview_window (void)
 	GtkWidget *quit, *close;
 	GtkWidget *dfview, *dfview_menu, *dvexternal, *dvhelp, *dvhelp_menu;
 	GtkWidget *dvhelpmenu, *image1, *about, *dvtoolbar;
-	GtkIconSize tmp_toolbar_icon_size;
 	GtkWidget *dvtoolnew, *separatortoolitem1, *dvtoolopen, *separatortoolitem3;
 	GtkWidget *dvtoolabout, *separatortoolitem2, *dvhelptoolbar, *separatortoolitem4;
 	GtkWidget *dvtoolclose, *dvtoolquit, *hbox4;
@@ -226,7 +225,7 @@ create_deb_gview_window (void)
 	gtk_widget_show (dvtoolbar);
 	gtk_box_pack_start (GTK_BOX (vbox4), dvtoolbar, FALSE, FALSE, 0);
 	gtk_toolbar_set_style (GTK_TOOLBAR (dvtoolbar), GTK_TOOLBAR_BOTH);
-	tmp_toolbar_icon_size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (dvtoolbar));
+	gtk_toolbar_get_icon_size (GTK_TOOLBAR (dvtoolbar));
 
 	dvtoolnew = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-new");
 	gtk_widget_show (dvtoolnew);
